@@ -54,6 +54,16 @@ class NumerousApp():
     def setup_scenario(self):
 
         self.scenario, self.model_definition, self.files = self.nc.get_scenario()
+        main_job = None
+        for job in self.scenario.get('jobs', {}).values():
+            if job.get('isMain', True):
+                main_job=job
+                break
+        if not main_job:
+            raise KeyError('no main job found on scenario')
+
+        self.nc._run_settings = None
+
         self.nc.set_scenario_progress('initializing', ScenarioStatus.ENVIRONMENT_INITIALIZING, 0.0, force=True)
 
         # Prepare simulation setup
